rankeval\.model package
=======================

.. automodule:: rankeval.model
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

rankeval\.model\.proxy\_LightGBM module
---------------------------------------

.. automodule:: rankeval.model.proxy_LightGBM
    :members:
    :undoc-members:
    :show-inheritance:

rankeval\.model\.proxy\_QuickRank module
----------------------------------------

.. automodule:: rankeval.model.proxy_QuickRank
    :members:
    :undoc-members:
    :show-inheritance:

rankeval\.model\.proxy\_ScikitLearn module
------------------------------------------

.. automodule:: rankeval.model.proxy_ScikitLearn
    :members:
    :undoc-members:
    :show-inheritance:

rankeval\.model\.proxy\_XGBoost module
--------------------------------------

.. automodule:: rankeval.model.proxy_XGBoost
    :members:
    :undoc-members:
    :show-inheritance:

rankeval\.model\.rt\_ensemble module
------------------------------------

.. automodule:: rankeval.model.rt_ensemble
    :members:
    :undoc-members:
    :show-inheritance:


